@@ -28,7 +28,12 @@ class TacticalController extends Controller
         $hoststateSummary = HoststateSummary::on($db);
         $servicestateSummary = ServicestateSummary::on($db);
 
-        $this->handleSearchRequest($servicestateSummary);
+        $this->handleSearchRequest($servicestateSummary, [
+            'host.name_ci',
+            'host.display_name',
+            'host.address',
+            'host.address6'
+        ]);
 
         $searchBar = $this->createSearchBar($servicestateSummary);
         if ($searchBar->hasBeenSent() && ! $searchBar->isValid()) {
@@ -86,11 +91,4 @@ class TacticalController extends Controller
         $this->getDocument()->add($editor);
         $this->setTitle(t('Adjust Filter'));
     }
-
-    protected function prepareSearchFilter(Query $query, string $search, Filter\Any $filter)
-    {
-        parent::prepareSearchFilter($query, $search, $filter);
-
-        $filter->add(Filter::like('host.name_ci', "*$search*"));
-    }
 }
