@@ -4,18 +4,17 @@
 
 namespace Icinga\Module\Icingadb\Forms\Command\Object;
 
-use Generator;
+use CallbackFilterIterator;
 use Icinga\Module\Icingadb\Command\Object\DeleteDowntimeCommand;
 use Icinga\Module\Icingadb\Forms\Command\CommandForm;
 use Icinga\Web\Notification;
-use ipl\Web\Common\RedirectOption;
+use ipl\Orm\Model;
 use ipl\Web\Widget\Icon;
+use Iterator;
 use Traversable;
 
 class DeleteDowntimeForm extends CommandForm
 {
-    use RedirectOption;
-
     protected $defaultAttributes = ['class' => 'inline'];
 
     public function __construct()
@@ -28,7 +27,7 @@ class DeleteDowntimeForm extends CommandForm
             $countObjects = count($this->getObjects());
 
             Notification::success(sprintf(
-                tp('Removed downtime successfully', 'Removed downtime from %d objects successfully', $countObjects),
+                tp('Removed downtime successfully', 'Removed %d downtimes successfully', $countObjects),
                 $countObjects
             ));
         });
@@ -36,7 +35,6 @@ class DeleteDowntimeForm extends CommandForm
 
     protected function assembleElements()
     {
-        $this->addElement($this->createRedirectOption());
     }
 
     protected function assembleSubmitButton()
@@ -66,25 +64,20 @@ class DeleteDowntimeForm extends CommandForm
         );
     }
 
-    protected function getCommands(Traversable $objects): Traversable
+    protected function getCommands(Iterator $objects): Traversable
     {
-        $granted = (function () use ($objects): Generator {
-            foreach ($objects as $object) {
-                if (
-                    $this->isGrantedOn('icingadb/command/downtime/delete', $object->{$object->object_type})
-                    && $object->scheduled_by === null
-                ) {
-                    yield $object;
-                }
-            }
-        })();
+        $granted = new CallbackFilterIterator($objects, function (Model $object): bool {
+            return $object->scheduled_by === null
+                && $this->isGrantedOn('icingadb/command/downtime/delete', $object->{$object->object_type});
+        });
 
+        $command = new DeleteDowntimeCommand();
+        $command->setAuthor($this->getAuth()->getUser()->getUsername());
+
+        $granted->rewind(); // Forwards the pointer to the first element
         if ($granted->valid()) {
-            $command = new DeleteDowntimeCommand();
-            $command->setObjects($granted);
-            $command->setAuthor($this->getAuth()->getUser()->getUsername());
-
-            yield $command;
+            // Chunk objects to avoid timeouts with large sets
+            yield $command->setObjects($granted)->setChunkSize(250);
         }
     }
 }
