@@ -14,6 +14,7 @@ use Icinga\Module\Icingadb\Hook\UserDetailExtensionHook;
 use Icinga\Module\Icingadb\Hook\UsergroupDetailExtensionHook;
 use Icinga\Module\Icingadb\Model\History;
 use Icinga\Module\Icingadb\Model\Host;
+use Icinga\Module\Icingadb\Model\RedundancyGroup;
 use Icinga\Module\Icingadb\Model\Service;
 use Icinga\Module\Icingadb\Model\User;
 use Icinga\Module\Icingadb\Model\Usergroup;
@@ -48,6 +49,9 @@ abstract class ObjectDetailExtensionHook extends BaseExtensionHook
             case $object instanceof Service:
                 $hookName = 'Icingadb\\ServiceDetailExtension';
                 break;
+            case $object instanceof RedundancyGroup:
+                $hookName = 'Icingadb\\RedundancyGroupDetailExtension';
+                break;
             case $object instanceof User:
                 $hookName = 'Icingadb\\UserDetailExtension';
                 break;
@@ -100,16 +104,22 @@ abstract class ObjectDetailExtensionHook extends BaseExtensionHook
                 // be caught here.
                 $extension = (string) $hook->getHtmlForObject(clone $object);
 
-                $moduleName = $hook->getModule()->getName();
+                if (! empty($extension)) {
+                    $moduleName = $hook->getModule()->getName();
 
-                $extensions[$location] = new HtmlElement(
-                    'div',
-                    Attributes::create([
-                        'class' => 'icinga-module module-' . $moduleName,
-                        'data-icinga-module' => $moduleName
-                    ]),
-                    HtmlString::create($extension)
-                );
+                    $extensions[$location] = new HtmlElement(
+                        'div',
+                        Attributes::create([
+                            'class' => 'icinga-module module-' . $moduleName,
+                            'data-icinga-module' => $moduleName
+                        ]),
+                        HtmlString::create($extension)
+                    );
+                } else {
+                    // There's no way for an extension to decide whether it should provide a result or not.
+                    // So, even if empty, the result must be used as it's perfectly valid.
+                    $extensions[$location] = HtmlString::create('');
+                }
             } catch (Throwable $e) {
                 Logger::error("Failed to load detail extension: %s\n%s", $e, $e->getTraceAsString());
                 $extensions[$location] = Text::create(IcingaException::describe($e));
