@@ -5,6 +5,7 @@
 namespace Icinga\Module\Icingadb\Hook;
 
 use Icinga\Application\Icinga;
+use Icinga\Authentication\Auth;
 use Icinga\Module\Icingadb\Hook\Common\HookUtils;
 use Icinga\Web\Session;
 
@@ -12,9 +13,6 @@ abstract class IcingadbSupportHook
 {
     use HookUtils;
 
-    /** @var string key name of preference */
-    const PREFERENCE_NAME = 'icingadb.as_backend';
-
     /**
      * Return whether your module supports IcingaDB or not
      *
@@ -32,19 +30,18 @@ abstract class IcingadbSupportHook
      */
     final public static function isIcingaDbSetAsPreferredBackend(): bool
     {
-        return (bool) Session::getSession()
-            ->getNamespace('icingadb')
-            ->get(self::PREFERENCE_NAME, false);
+        return true;
     }
 
     /**
      * Whether to use icingadb as the backend
      *
-     * @return bool Returns true if monitoring module is disabled or icingadb is selected as backend, false otherwise.
+     * @return bool Returns true if monitoring module is accessible or icingadb is selected as backend, false otherwise.
      */
     final public static function useIcingaDbAsBackend(): bool
     {
         return ! Icinga::app()->getModuleManager()->hasEnabled('monitoring')
+            || ! Auth::getInstance()->hasPermission('module/monitoring')
             || self::isIcingaDbSetAsPreferredBackend();
     }
 }
