@@ -4,10 +4,10 @@
 
 namespace Icinga\Module\Icingadb\Model;
 
+use Icinga\Module\Icingadb\Common\Model;
 use Icinga\Module\Icingadb\Model\Behavior\ActionAndNoteUrl;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
 /**
