@@ -4,11 +4,17 @@
 
 namespace Icinga\Module\Icingadb\Model;
 
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string $checkcommand_id
+ * @property string $customvar_id
+ * @property string $environment_id
+ */
 class CheckcommandCustomvar extends Model
 {
     public function getTableName()
