@@ -5,8 +5,9 @@
 namespace Icinga\Module\Icingadb\Model;
 
 use Icinga\Module\Icingadb\Common\Auth;
-use Icinga\Module\Icingadb\Model\Behavior\BoolCast;
+use Icinga\Module\Icingadb\Common\Backend;
 use Icinga\Module\Icingadb\Common\Model;
+use ipl\Orm\Behavior\BoolCast;
 use Icinga\Module\Icingadb\Model\Behavior\ReRoute;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
@@ -56,6 +57,7 @@ use ipl\Orm\ResultSet;
  * @property ?string $zone_id
  * @property string $command_endpoint_name
  * @property ?string $command_endpoint_id
+ * @property ?int $total_children
  */
 class Host extends Model
 {
@@ -73,7 +75,7 @@ class Host extends Model
 
     public function getColumns()
     {
-        return [
+        $columns = [
             'environment_id',
             'name_checksum',
             'properties_checksum',
@@ -113,11 +115,17 @@ class Host extends Model
             'command_endpoint_name',
             'command_endpoint_id'
         ];
+
+        if (Backend::supportsDependencies()) {
+            $columns[] = 'total_children';
+        }
+
+        return $columns;
     }
 
     public function getColumnDefinitions()
     {
-        return [
+        $columns = [
             'environment_id'            => t('Environment Id'),
             'name_checksum'             => t('Host Name Checksum'),
             'properties_checksum'       => t('Host Properties Checksum'),
@@ -135,7 +143,7 @@ class Host extends Model
             'check_timeperiod_id'       => t('Check Timeperiod Id'),
             'check_timeout'             => t('Host Check Timeout'),
             'check_interval'            => t('Host Check Interval'),
-            'check_retry_interval'      => t('Host Check Retry Inverval'),
+            'check_retry_interval'      => t('Host Check Retry Interval'),
             'active_checks_enabled'     => t('Host Active Checks Enabled'),
             'passive_checks_enabled'    => t('Host Passive Checks Enabled'),
             'event_handler_enabled'     => t('Host Event Handler Enabled'),
@@ -157,6 +165,12 @@ class Host extends Model
             'command_endpoint_name'     => t('Endpoint Name'),
             'command_endpoint_id'       => t('Endpoint Id')
         ];
+
+        if (Backend::supportsDependencies()) {
+            $columns['total_children'] = t('Total Children');
+        }
+
+        return $columns;
     }
 
     public function getSearchColumns()
@@ -181,6 +195,8 @@ class Host extends Model
         ]));
 
         $behaviors->add(new ReRoute([
+            'child'         => 'to.from',
+            'parent'        => 'from.to',
             'servicegroup'  => 'service.servicegroup',
             'user'          => 'notification.user',
             'usergroup'     => 'notification.usergroup'
@@ -235,6 +251,10 @@ class Host extends Model
 
     public function createRelations(Relations $relations)
     {
+        $relations->hasOne('state', HostState::class)->setJoinType('LEFT');
+        $relations->hasOne('dependency_node', DependencyNode::class)->setJoinType('LEFT');
+        $relations->hasOne('unreachable_parent', UnreachableParent::class)->setJoinType('LEFT');
+
         $relations->belongsTo('environment', Environment::class);
         $relations->belongsTo('eventcommand', Eventcommand::class);
         $relations->belongsTo('checkcommand', Checkcommand::class);
@@ -255,7 +275,8 @@ class Host extends Model
             ->setCandidateKey('command_endpoint_id');
 
         $relations->belongsToMany('customvar', Customvar::class)
-            ->through(HostCustomvar::class);
+            ->through(HostCustomvar::class)
+            ->setThroughAlias('t_host_customvar');
         $relations->belongsToMany('customvar_flat', CustomvarFlat::class)
             ->through(HostCustomvar::class);
         $relations->belongsToMany('vars', Vars::class)
@@ -263,12 +284,20 @@ class Host extends Model
         $relations->belongsToMany('hostgroup', Hostgroup::class)
             ->through(HostgroupMember::class);
 
-        $relations->hasOne('state', HostState::class)->setJoinType('LEFT');
         $relations->hasMany('comment', Comment::class)->setJoinType('LEFT');
         $relations->hasMany('downtime', Downtime::class)->setJoinType('LEFT');
         $relations->hasMany('history', History::class);
         $relations->hasMany('notification', Notification::class)->setJoinType('LEFT');
         $relations->hasMany('notification_history', NotificationHistory::class);
         $relations->hasMany('service', Service::class)->setJoinType('LEFT');
+
+        $relations->belongsToMany('from', DependencyEdge::class)
+            ->setTargetCandidateKey('from_node_id')
+            ->setTargetForeignKey('id')
+            ->through(DependencyNode::class);
+        $relations->belongsToMany('to', DependencyEdge::class)
+            ->setTargetCandidateKey('to_node_id')
+            ->setTargetForeignKey('id')
+            ->through(DependencyNode::class);
     }
 }
