@@ -7,9 +7,14 @@ namespace Icinga\Module\Icingadb\Model;
 use Icinga\Module\Icingadb\Model\Behavior\ActionAndNoteUrl;
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string[] $notes_url
+ * @property string $environment_id
+ */
 class NotesUrl extends Model
 {
     public function getTableName()
