@@ -6,9 +6,15 @@ namespace Icinga\Module\Icingadb\Model;
 
 use ipl\Orm\Behavior\Binary;
 use ipl\Orm\Behaviors;
-use ipl\Orm\Model;
+use Icinga\Module\Icingadb\Common\Model;
 use ipl\Orm\Relations;
 
+/**
+ * @property string $id
+ * @property string $servicegroup_id
+ * @property string $customvar_id
+ * @property string $environment_id
+ */
 class ServicegroupCustomvar extends Model
 {
     public function getTableName()
