@@ -37,8 +37,6 @@ use ipl\Html\ValidHtml;
 use ipl\Orm\Query;
 use ipl\Orm\UnionQuery;
 use ipl\Stdlib\Filter;
-use ipl\Web\Common\BaseItemList;
-use ipl\Web\Common\BaseItemTable;
 use ipl\Web\Compat\CompatController;
 use ipl\Web\Control\LimitControl;
 use ipl\Web\Control\PaginationControl;
@@ -104,7 +102,12 @@ class Controller extends CompatController
             }
         }
 
-        $query->withColumns($columns);
+        // When exporting as CSV or JSON, and the user requested specific columns, only those should be included
+        if ($this->format === 'csv' || $this->format === 'json') {
+            $query->columns($columns);
+        } else {
+            $query->withColumns($columns);
+        }
 
         if (! $viewMode) {
             $viewModeSwitcher->setViewMode('tabular');
@@ -187,10 +190,6 @@ class Controller extends CompatController
 
                 try {
                     $preferencesStore = PreferencesStore::create(new ConfigObject([
-                        //TODO: Don't set store key as it will no longer be needed once we drop support for
-                        // lower version of icingaweb2 then v2.11.
-                        //https://github.com/Icinga/icingaweb2/pull/4765
-                        'store'     => Config::app()->get('global', 'config_backend', 'db'),
                         'resource'  => Config::app()->get('global', 'config_resource')
                     ]), $user);
                     $preferencesStore->load();
@@ -307,10 +306,11 @@ class Controller extends CompatController
     {
         $columns = array_merge($query->getModel()->getSearchColumns(), $additionalColumns);
         foreach ($columns as $column) {
-            $filter->add(Filter::like(
-                $query->getResolver()->qualifyColumn($column, $query->getModel()->getTableName()),
-                "*$search*"
-            ));
+            if (strpos($column, '.') === false) {
+                $column = $query->getResolver()->qualifyColumn($column, $query->getModel()->getTableName());
+            }
+
+            $filter->add(Filter::like($column, "*$search*"));
         }
     }
 
@@ -367,7 +367,10 @@ class Controller extends CompatController
 
         // No matter the format, a limit should only apply if set
         if ($this->format !== null) {
-            $query->limit(Url::fromRequest()->getParam('limit'));
+            if (! Url::fromRequest()->hasParam('limit')) {
+                $query->limit(null)
+                    ->offset(null);
+            }
         }
 
         if ($this->format === 'json' || $this->format === 'csv') {
@@ -405,51 +408,6 @@ class Controller extends CompatController
         $this->getTabs()->enableDataExports();
     }
 
-    /**
-     * @todo Remove once support for Icinga Web 2 v2.9.x is dropped
-     */
-    protected function sendAsPdf()
-    {
-        if (! Icinga::app()->getModuleManager()->has('pdfexport')) {
-            throw new ConfigurationError('The pdfexport module is required for exports to PDF');
-        }
-
-        if (version_compare(Version::VERSION, '2.10.0', '>=')) {
-            parent::sendAsPdf();
-            return;
-        }
-
-        putenv('ICINGAWEB_EXPORT_FORMAT=pdf');
-        Environment::raiseMemoryLimit('512M');
-        Environment::raiseExecutionTime(300);
-
-        $time = DateFormatter::formatDateTime(time());
-
-        $doc = (new PrintableHtmlDocument())
-            ->setTitle($this->view->title ?? '')
-            ->setHeader(Html::wantHtml([
-                Html::tag('span', ['class' => 'title']),
-                Html::tag('time', null, $time)
-            ]))
-            ->setFooter(Html::wantHtml([
-                Html::tag('span', null, [
-                    t('Page') . ' ',
-                    Html::tag('span', ['class' => 'pageNumber']),
-                    ' / ',
-                    Html::tag('span', ['class' => 'totalPages'])
-                ]),
-                Html::tag('p', null, Url::fromRequest()->setParams($this->params))
-            ]))
-            ->addHtml($this->content);
-        $doc->getAttributes()->add('class', 'icinga-module module-icingadb');
-
-        Pdfexport::first()->streamPdfFromHtml($doc, sprintf(
-            '%s-%s',
-            $this->view->title ?: $this->getRequest()->getActionName(),
-            $time
-        ));
-    }
-
     public function dispatch($action)
     {
         // Notify helpers of action preDispatch state
@@ -482,9 +440,7 @@ class Controller extends CompatController
 
     protected function addContent(ValidHtml $content)
     {
-        if ($content instanceof BaseItemList || $content instanceof BaseItemTable) {
-            $this->content->getAttributes()->add('class', 'full-width');
-        } elseif ($content instanceof StateItemTable) {
+        if ($content instanceof StateItemTable) {
             $this->content->getAttributes()->add('class', 'full-height');
         }
 
@@ -512,7 +468,12 @@ class Controller extends CompatController
     {
         parent::preDispatch();
 
-        $this->format = $this->params->shift('format');
+        $this->format = $this->params->shift(
+            'format',
+            $this->getRequest()->isApiRequest()
+                ? 'json'
+                : null
+        );
     }
 
     public function postDispatch()
